| jumble | R Documentation |
A pretty discrete colour palette that is relatively accessible.
Note only the first 3 colours are safe for all forms of colourblindness, as well as greyscale.
An extra safe colour that works is jumble::grey i.e. jumble::jumble[c(1:4, 7)].
jumble
A character vector.
scales::show_col(jumble::jumble)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.