A pretty discrete colour palette that is relatively accessible.
Note only the first 3 colours are safe for all forms of colourblindness, as well as greyscale.
An extra safe colour that works is jumble::grey i.e. jumble[c(1:4, 7)].
Examples
scales::show_col(jumble)